require 'cocoapods-extension/sandbox'

module Pod
    class Command
        class Dev < Command
            class Open < Dev

                extend Executable
                executable :open

                self.summary = 'Open development project or workspace.'
                self.description = 'Open development project or workspace.'
                
                def self.options
                    [
                        ['--proj', 'Open development project.'],
                        ['--wks', 'Open development workspace.'],
                    ].concat(super)
                end
                
                def initialize(argv)
                    @wipe_proj = argv.flag?('proj')
                    @wipe_wks = argv.flag?('wks')
                    super
                end

                def run
                    if @wipe_proj
                        open_proj
                    end

                    if @wipe_wks
                        open_wks
                    end

                    if !@wipe_proj && !@wipe_wks
                        help!
                    end
                end

                def open_proj
                    project_url = Pathname(Dir.pwd) 
                    Pod::Extension::Sandbox::install!
                    Pod::Extension::Sandbox::podfile_exists! project_url
                    conf = Pod::Extension::Configurator::find_conf? project_url
                    if !conf.nil? && conf.verify?
                        UI.section("Opening project.") do
                            open! [conf::project_debug_url]
                        end
                    else
                        UI.puts "Please run `pod dev init`."
                    end
                end

                def open_wks
                    UI.section("Opening workspace.") do
                        open! [Pod::Extension::Sandbox::workspace::root]
                    end
                end

            end
        end
    end
end