module Pod
    class Command
        class XC < Command
            class Clean < XC

                self.summary = 'Remove the cache for xcode.'
                self.description = <<-DESC
                    Remove 'Pods' 'Podfile.lock' 'DerivedData'.
      
                    If there is multiple cache for various versions of the requested item,
                    you will be asked which one to clean. Use `--all` to clean them all.
                DESC
        
                def self.options
                    [
                        ['--all', 'Remove all the cached without asking']
                    ].concat(super)
                end

                def initialize(argv)
                    @cache_files = Hash.new
                    @cache_files['Pods'] = File.join(Dir.pwd, 'Pods')
                    @cache_files['Podfile.lock'] = File.join(Dir.pwd, 'Podfile.lock')
                    @cache_files['DerivedData'] = File.join(File.expand_path('~'), 'Library/Developer/Xcode/DerivedData')
                    @wipe_all = argv.flag?('all')
                    super
                end

                def run
                    if @wipe_all
                        remove_indexs ['Pods', 'Podfile.lock', 'DerivedData']
                    else
                        begin
                            choices = ['Pods', 'Podfile.lock', 'DerivedData', 'Pods and Podfile.lock', 'All']
                            index = UI.choose_from_array(choices, 'Which item do you want to remove?')
                            case index
                            when 0
                                remove_indexs ['Pods']
                            when 1
                                remove_indexs ['Podfile.lock']
                            when 2
                                remove_indexs ['DerivedData']
                            when 3
                                remove_indexs ['Pods', 'Podfile.lock']
                            when 4
                                remove_indexs ['Pods', 'Podfile.lock', 'DerivedData']
                            end
                        rescue => exception
                            UI.puts "[!] #{exception}".red
                        end
                    end

                end

                private 

                extend Executable
                executable :rm
                
                def remove_indexs indexs
                    indexs.each do |index| 
                        value = @cache_files[index]
                        unless value.nil?
                            UI.section("Removing #{index} => #{value}.") do
                                rm! ['-rf', value]
                            end
                        end
                    end
                end

            end
        end
    end
end