
module Pod
    module Extension
        class SourceDefinition

            attr_reader :domain
            attr_reader :parent
            attr_reader :children
            attr_reader :map

            def initialize(domain, parent)
                @domain = domain
                @parent = parent
                @children = []
                @map = Hash::new
                if parent.is_a?(Pod::Extension::SourceDefinition)
                    parent.children << self
                end
            end

            def source_list
                list = Hash::new(@map)
                for source in children do
                    list = list.merge(source.map)
                end
                list
            end

            def store_pod(name = nil, *requirements)
                options = requirements.last || Hash.new
                git = options[:git] || "#{name}.git"
                group = options[:group] || name

                if domain.start_with? "git@"
                    store_pod_git(name, group, git)
                elsif domain.size > 0
                    store_pod_http(name, group, git)
                end
            end

            def store_pod_git(name, group, git)
                source = "#{domain}:#{group}/#{git}"
                map[name] = source
            end

            def store_pod_http(name, group, git)
                source = Pathname(domain)
                source += group
                source += git
                map[name] = source.to_s
            end

        end

        class PodsDefinition
            
            attr_reader :map

            def initialize
                @map = Hash::new
            end

            def pods_list 
                @map
            end

            def store_pod(name = nil, *requirements)
                options = requirements.last || Hash::new
                share = options[:share].nil? ? true : options[:share]
                @map[name] = share
            end

        end

    end
end