require 'cocoapods-extension/sandbox'
require 'cocoapods-extension/configure'
require 'cocoapods-extension/development/dsl'

module Pod
    module Extension
        class Development

            attr_reader :source_definition, :pods_definition

            def self.development 
                @@shared ||= Pod::Extension::Development::new
                @@shared
            end

            def initialize
                @runing = false
                @project = nil
                @workspace = nil
                @pods_list = nil
                @source_list = nil
                @pods_definition = Pod::Extension::Development::Pods::new
                @source_definition = Pod::Extension::Development::Source::new
                run
            end

            def runing?
                @runing
            end

            def pods_list?
                @pods_list
            end

            def source_list?
                @source_list
            end

            def pod! name, source, share
                unless share 
                    repos = @project::repos
                else
                    repos = @workspace::repos
                end
                repos.pod! name, source, share
            end
                
            def run
                project_url = Dir.pwd
                conf = Pod::Extension::Configurator::find_conf? project_url
                return nil if conf.nil?

                @project = Pod::Extension::Sandbox::Project::new conf
                @project.install!
                pod_file = @project.pod_file
                return nil unless pod_file.exist?

                @workspace = Pod::Extension::Sandbox::workspace
                source_file = @workspace.source_file
                return nil unless source_file.exist?

                begin
                    @pods_definition::run pod_file
                    @source_definition::run source_file
                    @pods_list = @pods_definition.pods_list
                    @source_list = @source_definition.source_list
                    if @pods_list.size > 0 && @source_list.size > 0
                        @runing = true
                        UI.puts 'Pod::Extension::Development working.'.green
                    end
                rescue => exception
                    puts "[!] #{exception}".red
                end
            end

        end
    end
end

module Pod
    module Extension
        class Development

            class Source

                include Pod::Extension::Development::DSL
                include Pod::Extension::Development::SourceDSL

                attr_reader :parent
                attr_reader :current_domain_definition

                def initialize
                    @parent = Pod::Extension::SourceDefinition::new('', nil)
                end

                def source_list 
                    @parent::source_list
                end

            end

            class Pods

                include Pod::Extension::Development::DSL
                include Pod::Extension::Development::PodDSL

                attr_reader :current_pods_definition

                def initialize
                    @current_pods_definition = Pod::Extension::PodsDefinition::new
                end

                def pods_list 
                    @current_pods_definition::pods_list
                end

            end

        end
    end
end